@@ -1,11 +1,23 @@
+config() {
+  NEW="$1"
+  OLD="`dirname $NEW`/`basename $NEW .new`"
+  # If there's no config file by that name, mv it over:
+  if [ ! -r $OLD ]; then
+    mv $NEW $OLD
+  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
+    rm $NEW
+  fi
+  # Otherwise, we leave the .new copy for the admin to consider...
+}
+config etc/ssl/openssl.cnf.new
 ( cd usr/lib ; rm -rf libssl.so )
 ( cd usr/lib ; ln -sf libssl.so.0 libssl.so )
 ( cd usr/lib ; rm -rf libcrypto.so )
 ( cd usr/lib ; ln -sf libcrypto.so.0 libcrypto.so )
 ( cd usr/lib ; rm -rf libssl.so.0 )
-( cd usr/lib ; ln -sf libssl.so.0.9.7 libssl.so.0 )
+( cd usr/lib ; ln -sf libssl.so.0.9.8 libssl.so.0 )
 ( cd usr/lib ; rm -rf libcrypto.so.0 )
-( cd usr/lib ; ln -sf libcrypto.so.0.9.7 libcrypto.so.0 )
+( cd usr/lib ; ln -sf libcrypto.so.0.9.8 libcrypto.so.0 )
 ( cd usr/man/man1 ; rm -rf md4.1.gz )
 ( cd usr/man/man1 ; ln -sf dgst.1.gz md4.1.gz )
 ( cd usr/man/man1 ; rm -rf md5.1.gz )
@@ -50,6 +62,8 @@
 ( cd usr/man/man3 ; ln -sf SSL_CTX_use_certificate.3.gz SSL_CTX_use_RSAPrivateKey_ASN1.3.gz )
 ( cd usr/man/man3 ; rm -rf CRYPTO_set_locking_callback.3.gz )
 ( cd usr/man/man3 ; ln -sf threads.3.gz CRYPTO_set_locking_callback.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_invert.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_invert.3.gz )
 ( cd usr/man/man3 ; rm -rf SSL_CTX_use_PrivateKey.3.gz )
 ( cd usr/man/man3 ; ln -sf SSL_CTX_use_certificate.3.gz SSL_CTX_use_PrivateKey.3.gz )
 ( cd usr/man/man3 ; rm -rf SSL_CTX_sess_misses.3.gz )
@@ -76,6 +90,8 @@
 ( cd usr/man/man3 ; ln -sf BN_add.3.gz BN_mod_sqr.3.gz )
 ( cd usr/man/man3 ; rm -rf BN_set_word.3.gz )
 ( cd usr/man/man3 ; ln -sf BN_zero.3.gz BN_set_word.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_free.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_free.3.gz )
 ( cd usr/man/man3 ; rm -rf UI_get0_result.3.gz )
 ( cd usr/man/man3 ; ln -sf ui.3.gz UI_get0_result.3.gz )
 ( cd usr/man/man3 ; rm -rf bn_mul_normal.3.gz )
@@ -214,6 +230,8 @@
 ( cd usr/man/man3 ; ln -sf SSL_CTX_set_generate_session_id.3.gz SSL_has_matching_session_id.3.gz )
 ( cd usr/man/man3 ; rm -rf X509_NAME_get_entry.3.gz )
 ( cd usr/man/man3 ; ln -sf X509_NAME_get_index_by_NID.3.gz X509_NAME_get_entry.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_create_param.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_create_param.3.gz )
 ( cd usr/man/man3 ; rm -rf OBJ_obj2nid.3.gz )
 ( cd usr/man/man3 ; ln -sf OBJ_nid2obj.3.gz OBJ_obj2nid.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_int_ctrl.3.gz )
@@ -302,6 +320,8 @@
 ( cd usr/man/man3 ; ln -sf CONF_modules_free.3.gz CONF_modules_unload.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_puts.3.gz )
 ( cd usr/man/man3 ; ln -sf BIO_read.3.gz BIO_puts.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_get_thread_id.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_get_thread_id.3.gz )
 ( cd usr/man/man3 ; rm -rf bn_sqr_normal.3.gz )
 ( cd usr/man/man3 ; ln -sf bn_internal.3.gz bn_sqr_normal.3.gz )
 ( cd usr/man/man3 ; rm -rf DH_set_default_method.3.gz )
@@ -402,6 +422,8 @@
 ( cd usr/man/man3 ; ln -sf buffer.3.gz BUF_MEM_grow.3.gz )
 ( cd usr/man/man3 ; rm -rf lh_free.3.gz )
 ( cd usr/man/man3 ; ln -sf lhash.3.gz lh_free.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_set_flags.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_set_flags.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_set_accept_bios.3.gz )
 ( cd usr/man/man3 ; ln -sf BIO_s_accept.3.gz BIO_set_accept_bios.3.gz )
 ( cd usr/man/man3 ; rm -rf EVP_MAX_MD_SIZE.3.gz )
@@ -822,6 +844,8 @@
 ( cd usr/man/man3 ; ln -sf bn_internal.3.gz bn_expand.3.gz )
 ( cd usr/man/man3 ; rm -rf RSA_get_ex_data.3.gz )
 ( cd usr/man/man3 ; ln -sf RSA_get_ex_new_index.3.gz RSA_get_ex_data.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_get_flags.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_get_flags.3.gz )
 ( cd usr/man/man3 ; rm -rf EVP_CIPHER_CTX_set_padding.3.gz )
 ( cd usr/man/man3 ; ln -sf EVP_EncryptInit.3.gz EVP_CIPHER_CTX_set_padding.3.gz )
 ( cd usr/man/man3 ; rm -rf EVP_PKEY_get1_RSA.3.gz )
@@ -862,12 +886,16 @@
 ( cd usr/man/man3 ; ln -sf d2i_X509_REQ.3.gz i2d_X509_REQ_fp.3.gz )
 ( cd usr/man/man3 ; rm -rf BN_mod_exp.3.gz )
 ( cd usr/man/man3 ; ln -sf BN_add.3.gz BN_mod_exp.3.gz )
+( cd usr/man/man3 ; rm -rf ERR_pop_to_mark.3.gz )
+( cd usr/man/man3 ; ln -sf ERR_set_mark.3.gz ERR_pop_to_mark.3.gz )
 ( cd usr/man/man3 ; rm -rf d2i_X509_CRL_bio.3.gz )
 ( cd usr/man/man3 ; ln -sf d2i_X509_CRL.3.gz d2i_X509_CRL_bio.3.gz )
 ( cd usr/man/man3 ; rm -rf SSL_set_ex_data.3.gz )
 ( cd usr/man/man3 ; ln -sf SSL_get_ex_new_index.3.gz SSL_set_ex_data.3.gz )
 ( cd usr/man/man3 ; rm -rf RSA_blinding_off.3.gz )
 ( cd usr/man/man3 ; ln -sf RSA_blinding_on.3.gz RSA_blinding_off.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_set_thread_id.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_set_thread_id.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_reset.3.gz )
 ( cd usr/man/man3 ; ln -sf BIO_ctrl.3.gz BIO_reset.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_set_nbio_accept.3.gz )
@@ -994,6 +1022,8 @@
 ( cd usr/man/man3 ; ln -sf SSL_want.3.gz SSL_want_nothing.3.gz )
 ( cd usr/man/man3 ; rm -rf i2d_X509_CRL_bio.3.gz )
 ( cd usr/man/man3 ; ln -sf d2i_X509_CRL.3.gz i2d_X509_CRL_bio.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_update.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_update.3.gz )
 ( cd usr/man/man3 ; rm -rf bn_mul_comba4.3.gz )
 ( cd usr/man/man3 ; ln -sf bn_internal.3.gz bn_mul_comba4.3.gz )
 ( cd usr/man/man3 ; rm -rf BN_is_one.3.gz )
@@ -1040,6 +1070,8 @@
 ( cd usr/man/man3 ; ln -sf d2i_X509.3.gz i2d_X509.3.gz )
 ( cd usr/man/man3 ; rm -rf BIO_new_buffer_ssl_connect.3.gz )
 ( cd usr/man/man3 ; ln -sf BIO_f_ssl.3.gz BIO_new_buffer_ssl_connect.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_convert.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_convert.3.gz )
 ( cd usr/man/man3 ; rm -rf SSL_set_quiet_shutdown.3.gz )
 ( cd usr/man/man3 ; ln -sf SSL_CTX_set_quiet_shutdown.3.gz SSL_set_quiet_shutdown.3.gz )
 ( cd usr/man/man3 ; rm -rf ASN1_STRING_dup.3.gz )
@@ -1074,6 +1106,8 @@
 ( cd usr/man/man3 ; ln -sf d2i_PKCS8PrivateKey.3.gz i2d_PKCS8PrivateKey_nid_fp.3.gz )
 ( cd usr/man/man3 ; rm -rf ERR_peek_last_error_line_data.3.gz )
 ( cd usr/man/man3 ; ln -sf ERR_get_error.3.gz ERR_peek_last_error_line_data.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_convert_ex.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_convert_ex.3.gz )
 ( cd usr/man/man3 ; rm -rf bn_mul_comba8.3.gz )
 ( cd usr/man/man3 ; ln -sf bn_internal.3.gz bn_mul_comba8.3.gz )
 ( cd usr/man/man3 ; rm -rf RSA_new_method.3.gz )
@@ -1400,6 +1434,10 @@
 ( cd usr/man/man3 ; ln -sf rc4.3.gz RC4.3.gz )
 ( cd usr/man/man3 ; rm -rf UI_add_verify_string.3.gz )
 ( cd usr/man/man3 ; ln -sf ui.3.gz UI_add_verify_string.3.gz )
+( cd usr/man/man3 ; rm -rf BN_BLINDING_invert_ex.3.gz )
+( cd usr/man/man3 ; ln -sf BN_BLINDING_new.3.gz BN_BLINDING_invert_ex.3.gz )
+( cd usr/man/man3 ; rm -rf ASN1_generate_v3.3.gz )
+( cd usr/man/man3 ; ln -sf ASN1_generate_nconf.3.gz ASN1_generate_v3.3.gz )
 ( cd usr/man/man3 ; rm -rf DES_set_key_checked.3.gz )
 ( cd usr/man/man3 ; ln -sf des.3.gz DES_set_key_checked.3.gz )
 ( cd usr/man/man3 ; rm -rf UI_get_method.3.gz )
@@ -1432,5 +1470,5 @@
 ( cd usr/man/man3 ; ln -sf ui.3.gz UI_construct_prompt.3.gz )
 ( cd usr/man/man3 ; rm -rf UI_get0_user_data.3.gz )
 ( cd usr/man/man3 ; ln -sf ui.3.gz UI_get0_user_data.3.gz )
-( cd usr/man/man7 ; rm -rf Modes )
-( cd usr/man/man7 ; ln -sf DES.7 Modes )
+( cd usr/man/man7 ; rm -rf Modes_of_DES.7.gz )
+( cd usr/man/man7 ; ln -sf des_modes.7.gz Modes_of_DES.7.gz )
